@@ -1,3 +1,5 @@
+import os
+
 import boto3
 
 
@@ -18,3 +20,11 @@ class ContextObject:
     @property
     def logs(self):
         return self._logs
+
+    @property
+    def aws_region(self):
+        return os.environ.get("AWS_REGION", os.environ.get("AWS_DEFAULT_REGION"))
+
+    @property
+    def aws_account_id(self):
+        return boto3.client("sts").get_caller_identity().get("Account")
